Here the People are listed who developed this software. The wrappers have
partly been implemented using hand coded wrappers, partly using SWIG (see
http://www.swig.org). Here the people are credited and the used tools are
listed. "Test" indicates if tests exist.

Packaging and integration
=========================


Devops usage at github, pypi packaging
--------------------------------------
Charl

building pygsl:
---------------
Achim, Pierre,

building rpms:
--------------
Leonardo Milano


Parts:
======

rng:
----
Achim, Pierre, c Module
Test

rng distributions:
------------------
Achim, Pierre, c Module

histogram:
----------
Achim, c Module, python types
Test

ieee:
-----
Achim, c Module, python functions
Test

specialfuctions:
----------------
Achim, c Module, python function

polynomials:
------------
Pierre, c Module, swig, python class
Test

matrix:
-------
Achim, c Module,

error:
------
Achim, Pierre, python Module, python exceptions

polynomials:
------------
Pierre, c Module swig, python class
Test

permutation:
------------
Fabian, c Module swig
Test

blas, linalg, eigen:
--------------------
Fabian
Test

numerical integration:
----------------------
Pierre c Module swig, python class
Test

statistics:
-----------
Jochen, c Modules
Test

histogram:
----------
Achim, c Module, c Type

siman:
------
Jochen, Pierre, c Module

multimin:
---------
Achim, c Module

odeiv:
------
Pierre, swig
Test

interpolation:
--------------
Pierre, swig
Test

numerical differntiation:
-------------------------
Jochen, Pierre, c Module

Chebyshev Approximations:
-------------------------
Pierre, swig

One dim Minimization:
---------------------
Pierre, swig
Test

One dim Root-Finding:
---------------------
Pierre, swig
Test

Multi-dim Root-Finding:
-----------------------
Pierre, swig
Test

Least-Square-Fitting:
---------------------
Pierre, swig
Test

Nonlinear Least Squares Fitting:
--------------------------------
Pierre, swig
Test

num. constants:
---------------
Achim

complex:
--------
-> Numeric

sorting:
---------------------
See TODO

vectors:
--------
not done

n-tuples:
---------
not done

fft, hankel transformation:
---------------------------
not done

series acceleration:
--------------------
not done


Documentation:
--------------
Achim, Jochen


Port of PyGSL to the MAC
------------------------
Pierre
Eric Gurrola
Peter Stoltz

Participants at the first informal pygsl nano workshop:
-------------------------------------------------------
17. 5. 02003. Darmstadt, Germany
Achim, Pierre ;-) Proceedings available soon.
